function [Vo] = hb_dsc(Vo, Data)
% New values for optimization variables Vo
% that are linked to discrete values of some design variables Vd (b and h)
%
% Variables:
%     1   2    3  4    5      6     7      8     9      10    11     12
%     f  teta  b  h  phi_py  n_py  phi_y  n_y  phi_px  n_px  phi_x  n_x
% _________________________________________________________________________

    if length(Data) == 24
%              1 2 3 4 5 6 7
%                  _ _  
        Var = [0 0 3 4 0 0 0];
        Max = Data(1,19:24);
    elseif length(Data) == 25
%              1 2 3 4 5 6 7 8
%                  _ _  
        Var = [0 0 3 4 0 0 0 0];
        Max = Data(1,19:25);    
    elseif length(Data) == 29
%              1 2 3 4 5 6 7 8 9 10 11 12
%                  _ _
        Var = [0 0 3 4 0 0 0 0 0  0  0  0];
        Max = Data(1,19:29);        
    end

    Vd_tmp = zeros(1,length(Var));
    Vo_tmp = Vo;
    for iloop = 1 : length(Var)
        if Var(iloop) ~= 0
            value = 0;
            Vd_tmp(iloop) = Vo_tmp(iloop) .* Max(iloop-1);
            Vd_tmp(iloop) = round(Vd_tmp(iloop));
            n = length(int2str(Vd_tmp(iloop)));
            CARACT = zeros(n,1);
            for jloop = 1 : n
                CARACT(jloop,1) = rem(Vd_tmp(iloop),(10^jloop))-...
                                  rem(Vd_tmp(iloop),(10^(jloop-1)));
                CARACT(jloop,1) = CARACT(jloop,1) / (10^(jloop-1));
            end
            % rounds every 5 mm
            if CARACT(1,1) < 3
                CARACT(1,1) = 0;
            elseif CARACT(1,1) < 8
                CARACT(1,1) = 5;
            else
                CARACT(1,1) = 0;
                if n > 1
                    CARACT(2,1) = CARACT(2,1) + 1;
                else
                    CARACT(2,1) = 1;
                end
            end
            for jloop = 1 : n
                value = value + CARACT(jloop,1) * (10 ^ (jloop-1));
            end
            Vd_tmp(iloop) = value;
            Vo_tmp(iloop) = Vd_tmp(iloop) ./ Max(iloop-1);
        end
    end
    Vo = Vo_tmp;
end
