function factor = mpfa_alpha(k, kmax, xc, speed)
% Function for the quadratic reduction of the alpha parameter
% _________________________________________________________________________

%   Coefficients of the function: factor = a * x ^ 2 + b * x + c;
%   with x = k / kmax
    if ~ speed
%       With zero slope at x = xc (slow randomness reduction)
        a = -1 / (1 - 2 * xc + xc ^ 2);
        b = (2 * xc) / (1 - 2 * xc + xc ^ 2);
        c = (1 - 2 * xc) / (1 - 2 * xc + xc ^ 2);
    else
%       With zero slope at x = 1 (fast randomization reduction)
        a = 1 / (1 - 2 * xc + xc ^ 2);
        b = -2 / (1 - 2 * xc + xc ^ 2);
        c = a;
    end

    if k / kmax < xc      % does not reduce advance step randomness
        factor = 1;
    else                  % quadratic reduction
        factor = a * (k / kmax) ^ 2 + b * (k / kmax) + c;
    end

end
