function [Vo] = phi_dsc(Vo, Data)
% New values for optimization variables Vo
% that are linked to discrete values of some design variables Vd
% (diameter of reinforcement bars)
%
% Variables:
%     1   2    3  4    5      6     7      8     9      10    11     12
%     f  teta  b  h  phi_py  n_py  phi_y  n_y  phi_px  n_px  phi_x  n_x
% _________________________________________________________________________

    if length(Data) == 24
%              1 2 3 4 5 6 7
%                      _
        Var = [0 0 0 0 5 0 0];
        Max = Data(1,19:24);
    elseif length(Data) == 25
%              1 2 3 4 5 6 7 8
%                      _   _
        Var = [0 0 0 0 5 0 7 0];
        Max = Data(1,19:25);    
    elseif length(Data) == 29
%              1 2 3 4 5 6 7 8 9 10 11 12
%                      _   _   _    __
        Var = [0 0 0 0 5 0 7 0 9  0 11  0];
        Max = Data(1,19:29);        
    end

    Vo_tmp= Vo;
    for iloop = 1 : length(Var)
        if Var(iloop) ~= 0
            value = Vo_tmp(iloop) .* Max(iloop-1);
            if le(value, 6)
                v_l = 6;
                v_u = 6;
            elseif le(value, 8)
                v_l = 6;
                v_u = 8;
            elseif le(value, 10)
                v_l = 8;
                v_u = 10;
            elseif le(value, 12)
                v_l = 10;
                v_u = 12;
            elseif le(value, 14)
                v_l = 12;
                v_u = 14;
            elseif le(value, 16)
                v_l = 14;
                v_u = 16;
            elseif le(value, 20)
                v_l = 16;
                v_u = 20;
            elseif le(value, 25)
                v_l = 20;
                v_u = 25;
            elseif le(value, 32)
                v_l = 25;
                v_u = 32;
            else
                v_l = 32;
                v_u = 40;
            end
            guess = randi([v_l v_u],1);
            if gt(value - guess,0)
                value = v_u;
            else
                value = v_l;
            end                        
            Vo_tmp(iloop) = value ./ Max(iloop-1);
        end
    end
    Vo = Vo_tmp;
end
